People - 用户
=============

..  topic:: 注意

    请先查看 :doc:`说明 <intro>` 了解一下知乎相关类的文档的阅读方法。
    否则你会看不懂下面的东西的…………

.. topic:: 关于用户关注的收藏夹

    由于知乎的 API 不允许获取其他用户关注的专栏（APP 上也没法查看到），所以暂时将
    :any:`following_collections` 移动到了 :any:`Me` 类中。

..  autoclass:: zhihu_oauth.zhcls.people.People
    :members:
    :undoc-members:

..  autoclass:: zhihu_oauth.zhcls.people.Badge
    :members:
    :undoc-members:
